#
# spec file for package maven-doxia
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-doxia
VCS: https://src.suse.de/SLFO-pool/maven-doxia#2f006cd8d4287c4d8a497f65e87697937956412028ab670268b6b46e6343c972
Version:        2.0.0
Release:        160000.1.3
Summary:        Content generation framework
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/doxia/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.tar.xz
Source2:        https://www.apache.org/licenses/LICENSE-2.0.txt
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-text
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  jetbrains-annotations
BuildRequires:  modello
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  sisu-inject
BuildRequires:  slf4j
BuildArch:      noarch

%description
Doxia is a content generation framework which provides techniques for
generating static and dynamic content. Doxia can be used to generate
static sites in addition to being incorporated into dynamic content
generation systems like blogs, wikis and content management systems.

%package core
Summary:        Core module for %{name}
Group:          Development/Libraries/Java
# Make the upgrades easier. The last version
# before 2.0.0 was 1.12.0
Obsoletes:      %{name}-logging-api < 1.13
Obsoletes:      %{name}-module-confluence < 1.13
Obsoletes:      %{name}-module-docbook-simple < 1.13
Obsoletes:      %{name}-module-fo < 1.13
Obsoletes:      %{name}-module-itext < 1.13
Obsoletes:      %{name}-module-latex < 1.13
Obsoletes:      %{name}-module-markdown < 1.13
Obsoletes:      %{name}-module-rtf < 1.13
Obsoletes:      %{name}-module-twiki < 1.13
Obsoletes:      %{name}-module-xhtml < 1.13

%description core
This package provides %{summary}.

%package module-apt
Summary:        APT module for %{name}
Group:          Development/Libraries/Java

%description module-apt
This package provides %{summary}.

%package module-fml
Summary:        FML module for %{name}
Group:          Development/Libraries/Java

%description module-fml
This package provides %{summary}.

%package module-xdoc
Summary:        XDoc module for %{name}
Group:          Development/Libraries/Java

%description module-xdoc
This package provides %{summary}.

%package module-xhtml5
Summary:        XHTML5 module for %{name}
Group:          Development/Libraries/Java

%description module-xhtml5
This package provides %{summary}.

%package sink-api
Summary:        Sink-api module for %{name}
Group:          Development/Libraries/Java

%description sink-api
This package provides %{summary}.

%package test-docs
Summary:        Test-docs module for %{name}
Group:          Development/Libraries/Java

%description test-docs
This package provides %{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -a1
cp %{SOURCE2} LICENSE

%build
mkdir -p lib
build-jar-repository -s lib \
    apache-commons-lang3 \
    apache-commons-text/commons-text \
    atinject \
    commons-io \
    jetbrains-annotations \
    org.eclipse.sisu.inject \
    plexus/utils \
    plexus/xml \
    slf4j/api

ant package javadoc

mkdir -p target/site/apidocs

%install
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}

for i in \
    doxia-sink-api \
    doxia-test-docs \
    doxia-core; do
  install -pm 0644 ${i}/target/${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${i}.jar
  %{mvn_install_pom} ${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/${i}.pom
  %add_maven_depmap %{name}/${i}.pom %{name}/${i}.jar -f ${i}
  if [ -d ${i}/target/site/apidocs ]; then
    cp -r ${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
  fi
done

for i in \
    doxia-module-apt \
    doxia-module-fml \
    doxia-module-xdoc \
    doxia-module-xhtml5; do
  install -pm 0644 doxia-modules/${i}/target/${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${i}.jar
  %{mvn_install_pom} doxia-modules/${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/${i}.pom
  %add_maven_depmap %{name}/${i}.pom %{name}/${i}.jar -f ${i}
  if [ -d doxia-modules/${i}/target/site/apidocs ]; then
    cp -r doxia-modules/${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
  fi
done

%fdupes -s %{buildroot}%{_javadocdir}

%files core -f .mfiles-doxia-core
%license LICENSE

%files module-apt -f .mfiles-doxia-module-apt

%files module-fml -f .mfiles-doxia-module-fml

%files module-xdoc -f .mfiles-doxia-module-xdoc

%files module-xhtml5 -f .mfiles-doxia-module-xhtml5

%files sink-api -f .mfiles-doxia-sink-api

%files test-docs -f .mfiles-doxia-test-docs

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Thu Oct  3 2024 fstrba@suse.com
- Upgrade to upstream version 2.0.0
  * Sub-task
    + DOXIA-599: Replace <a /> element's name attribute with id
    attribute
    + DOXIA-668: Remove all obsolete attributes in HTML5
    + DOXIA-672: Parse id attribute only on <a /> elements by
    default
    + DOXIA-674: Replace table border handling with new CSS class
    + DOXIA-675: Replace table alignment attributes with CSS styles
  * Bug
    + DOXIA-590: Either provided element class or default class
    gets ignored
    + DOXIA-598: Generated XHTML5 content does not pass W3 HTML5
    Validation Service
    + DOXIA-619: Sink.sectionTitle1() creates <h2> instead of <h1>
    + DOXIA-641: AptParser throws exception if title is not present
    + DOXIA-649: Plexus to Sisu migration missed singleton
    annotation
    + DOXIA-662: Non unique IDs generated by IndexingSink
    + DOXIA-671: Double quotes contained in markdown page are
    removed in HTML output
    + DOXIA-689: Restore incorrectly removed (HTML5) attributes
    + DOXIA-690: Markdown Parser: Multiline metadata incorrectly
    rendered
    + DOXIA-691: APT: Emit multiple authors in separate meta tags
    + DOXIA-692: Markdown Sink: Incorrect escape characters
    + DOXIA-693: Markdown Sink: Incorrect ordered list item prefixes
    + DOXIA-694: Markdown Sink: Too many line separators
    + DOXIA-695: Support of h6 in xhtml output is broken
    + DOXIA-699: Xhtml5Parser may emit sectionX() without
    sectionX_() when using both <hX> and <section>
    + DOXIA-704: style and class attributes not merged when
    user-supplied in XHTML5 sink
    + DOXIA-706: Sink.text(String, SinkEventAttributes) not properly
    supported by Xhtml5BaseSink
    + DOXIA-714: MarkdownSink: Fix table justification and figures
    + DOXIA-715: Sink.text(String, SinkEventAttributes) not properly
    supported by AptSink and MarkdownSink
    + DOXIA-724: Sink pipeline returned by
    AbstractParser.getWrappedSink(...) has wrong order
    + DOXIA-726: MarkdownSink: Incorrect escaping of <,>,",' and &
    + DOXIA-727: MarkdownSink: Incorrect escaping inside code spans
    + DOXIA-734: XHTML 1.0 elements/attributes which are obsolete in
    XHTML5 no longer detected by XdocParser/FmlParser
    + DOXIA-737: [REGRESSION] Making EmitAnchorsForIndexableEntries
    by default does not extract document titles anymore
    + DOXIA-740: Rendering Markdown silently truncates files that
    skip a heading level
  * New Feature
    + DOXIA-569: Add Markdown Sink to be able to convert anything to
    Markdown
    + DOXIA-660: Add ability to hide table rows via CSS
    + DOXIA-722: Optionally create anchors for indexable entries
    (used in TOC macro)
  * Improvement
    + DOXIA-617: doxia-module-markdown: Add support for --- header
    section marks
    + DOXIA-665: Add anchors around FML parts
    + DOXIA-667: Add <summary> and <details> to recognized tag list
    + DOXIA-669: Improve/rework CachedFileEntityResolver
    + DOXIA-676: Remove all obsolete elements in HTML5 and add new
    ones
    + DOXIA-679: Introduce Sink#tableRows(void) method
    + DOXIA-680: Don't wrap elements in anchors
    + DOXIA-684: replace flexmark-all dependency with core + only
    the used extensions
    + DOXIA-685: Replace SinkEventAttributes#BOXED with #SOURCE to
    clearly separate between regular verbatim and verbatim source
    (code)
    + DOXIA-687: Introduce Sink#verbatim(void) method
    + DOXIA-700: Streamline, update and simplify Doxia ID generation
    + DOXIA-709: Clarify usage of overlapping Sink methods
    + DOXIA-711: Introduce SinkWrapper with factory
    + DOXIA-716: Update and unify XMLReader creation and
    configuration
    + DOXIA-723: Optionally expose document location in Sink
    + DOXIA-728: MarkdownSink: Support blockquotes
    + DOXIA-731: Simplify HTML emitted from Sink.verbatim(...)
    + DOXIA-732: Do not fail for duplicate anchor names
    + DOXIA-738: Add Footnote extention for Markdown module
    + DOXIA-739: Disable source code highlighters for verbatim
    blocks for Markdown
  * Task
    + DOXIA-534: Remove Doxia Logging API
    + DOXIA-630: Remove all deprecated modules
    + DOXIA-631: Remove all deprecated macros
    + DOXIA-632: Remove remaining deprecated code
    + DOXIA-633: Drop and replace usage of HttpComponents in Core
    + DOXIA-634: Drop and replace usage of Commons Lang in Core
    + DOXIA-635: Drop and replace usage of Commons IO in Markdown
    Module
    + DOXIA-638: Replace Plexus Container Default with Sisu Plexus
    Shim
    + DOXIA-643: Upgrade to Java 8
    + DOXIA-644: Replace Plexus Annotations with Java Inject along
    with JUnit 5
    + DOXIA-645: Clean up exceptions
    + DOXIA-650: Make MarkdownParser to be a text parser with text
    markup
    + DOXIA-652: Drop build-info.properties in favor of default
    pom.properties
    + DOXIA-656: Make XHTML5 default implementation of HTML
    + DOXIA-657: Deprecate XHML(4) module
    + DOXIA-663: Remove deprecated XHTML module
    + DOXIA-666: Remove code duplication Xhtml5Sink
    + DOXIA-670: Drop dead XdocSink#link(String, String) method
    + DOXIA-673: Remove compat handling of absent Sink#tableRows()
    calls
    + DOXIA-678: Add missing elements in Xhtml5BaseParser
    + DOXIA-688: Remove empty alt attribute value on images which
    causes the browser not to render replacement icon
    + DOXIA-702: Fix dependency warnings in Markdown module
    + DOXIA-705: Remove remaining deprecated/duplicated code
- Removed patch:
  * 0002-Commons-configuration2.patch
    + The upstream version is already ported to
    commons-configuration2
* Sun Sep 29 2024 fstrba@suse.com
- A runtime dependency needs to be resolved with %%%%mvn_install
* Mon Jun 10 2024 fstrba@suse.com
- Use plexus-metadata-generator executable directly to simplify
  build classpath
* Tue Apr  2 2024 fstrba@suse.com
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 fstrba@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Sep 26 2023 fstrba@suse.com
- Added patch:
  * 0002-Commons-configuration2.patch
    + port to commons-configuration2 in order to remove dependency
    on old commons-lang
* Sat Sep 23 2023 fstrba@suse.com
- Upgrade to upstream version 1.12.0
  * Changes
    + DOXIA-409: Upgrade to FOP 2.2
    + DOXIA-497: Fix rendering links and paragraphs inside tables
    + DOXIA-584: Rewrite .md and .markdown links to .html
    + DOXIA-576 Upgrade HttpComponents: httpclient to 4.5.8 and
    httpcore to 4.4.11
    + DOXIA-570: Escape links to xml based figureGraphics image
    elements
    + SECURITY: Use HTTPS to resolve dependencies in Maven Build
    + MNGSITE-393: remove old Maven 1 and 2 info
    + DOXIA-612: update commons-lang to 3.8.1
    + DOXIA-610: Drop dependency to outdated Log4j
    + Fix Java 7 compatibility that was broken with DOXIA-616
    + DOXIA-618: import tests from maven-site-plugin
    + DOXIA-609: Fixed crosslinks starting with a dot in markdown
    files
    + replace deprecated class from commons-lang
    + fill in some generic types
- Removed patch:
  * 0001-Fix-itext-dependency.patch
    + no need to patch a module that we disable
* Fri May 13 2022 fstrba@suse.com
- Fix build with modello 2.0.0
* Tue Feb 22 2022 fstrba@suse.com
- Do not build against the log4j12 packages
* Tue Feb 22 2022 fstrba@suse.com
- Fix the version of the log4j that doxia-module-fo needs at
  runtime
* Tue May 11 2021 fstrba@suse.com
- Do not build against the legacy guava20 any more
* Sat Mar 14 2020 fstrba@suse.com
- Set obsoletes to make upgrades easier
* Wed Mar 11 2020 fstrba@suse.com
- Update to upstream version 1.9.1
- Removed patches:
  * 0002-Update-to-Plexus-Container-1.5.5.patch
  * 0003-Disable-tests-which-rely-on-ordering-in-set.patch
  * 0004-Port-to-fop-2.0.patch
    + Not needed in this build any more
* Tue Oct  1 2019 fstrba@suse.com
- Build against the compatibility package log4j12
* Thu Apr  4 2019 jengelh@inai.de
- Trim marketing and filler wording from description.
* Thu Mar 28 2019 fstrba@suse.com
- Initial packaging of maven-doxia 1.7
- Generate and customize ant build files
